==> sgq-business-0.3-sources.jar: com/herbocailleau/sgq/entities/Batch.java <==
package com.herbocailleau.sgq.entities;

import java.util.Date;
import org.nuiton.topia.persistence.TopiaEntity;

public interface Batch extends TopiaEntity {

    String PROPERTY_NUMBER = "number";

    String PROPERTY_ORDER_NUMBER = "orderNumber";

    String PROPERTY_ENTRY_DATE = "entryDate";

    String PROPERTY_DMESD = "dmesd";

    String PROPERTY_DPMES = "dpmes";

    String PROPERTY_DLUO = "dluo";

    String PROPERTY_ELAPSED_DATE = "elapsedDate";

    String PROPERTY_QUANTITY = "quantity";

    String PROPERTY_PACKAGE_COUNT = "packageCount";

    String PROPERTY_SAMPLE_CODE = "sampleCode";

    String PROPERTY_COMMENT = "comment";

    String PROPERTY_IMPORT_HASH = "importHash";

    String PROPERTY_INVALID = "invalid";

    String PROPERTY_SUPPLIER = "supplier";

    String PROPERTY_PRODUCT = "product";

    String PROPERTY_DEDICATED_CLIENT = "dedicatedClient";

    String PROPERTY_ORIGIN = "origin";

    void setNumber(int number);

    int getNumber();

    void setOrderNumber(long orderNumber);

    long getOrderNumber();

    void setEntryDate(Date entryDate);

    Date getEntryDate();

    void setDmesd(Date dmesd);

    Date getDmesd();

    void setDpmes(Date dpmes);

    Date getDpmes();

    void setDluo(Date dluo);

    Date getDluo();

    void setElapsedDate(Date elapsedDate);

    Date getElapsedDate();

    void setQuantity(double quantity);

    double getQuantity();

    void setPackageCount(int packageCount);

    int getPackageCount();

    void setSampleCode(String sampleCode);

    String getSampleCode();

    void setComment(String comment);

    String getComment();

    void setImportHash(String importHash);

    String getImportHash();

    void setInvalid(boolean invalid);

    boolean isInvalid();

    boolean getInvalid();

    void setSupplier(Supplier supplier);

    Supplier getSupplier();

    void setProduct(Product product);

    Product getProduct();

    void setDedicatedClient(Client dedicatedClient);

    Client getDedicatedClient();

    void setOrigin(Country origin);

    Country getOrigin();

} //Batch

==> sgq-business-0.4-sources.jar: com/herbocailleau/sgq/entities/Batch.java <==
package com.herbocailleau.sgq.entities;

import java.util.Date;
import org.nuiton.topia.persistence.TopiaEntity;

public interface Batch extends TopiaEntity {

    String PROPERTY_NUMBER = "number";

    String PROPERTY_ORDER_NUMBER = "orderNumber";

    String PROPERTY_ENTRY_DATE = "entryDate";

    String PROPERTY_DMESD = "dmesd";

    String PROPERTY_DPMES = "dpmes";

    String PROPERTY_DLUO = "dluo";

    String PROPERTY_EXPIRED_DATE = "expiredDate";

    String PROPERTY_QUANTITY = "quantity";

    String PROPERTY_PACKAGE_COUNT = "packageCount";

    String PROPERTY_SAMPLE_CODE = "sampleCode";

    String PROPERTY_COMMENT = "comment";

    String PROPERTY_IMPORT_HASH = "importHash";

    String PROPERTY_INVALID = "invalid";

    String PROPERTY_SUPPLIER = "supplier";

    String PROPERTY_PRODUCT = "product";

    String PROPERTY_DEDICATED_CLIENT = "dedicatedClient";

    String PROPERTY_ORIGIN = "origin";

    void setNumber(int number);

    int getNumber();

    void setOrderNumber(long orderNumber);

    long getOrderNumber();

    void setEntryDate(Date entryDate);

    Date getEntryDate();

    void setDmesd(Date dmesd);

    Date getDmesd();

    void setDpmes(Date dpmes);

    Date getDpmes();

    void setDluo(Date dluo);

    Date getDluo();

    void setExpiredDate(Date expiredDate);

    Date getExpiredDate();

    void setQuantity(double quantity);

    double getQuantity();

    void setPackageCount(int packageCount);

    int getPackageCount();

    void setSampleCode(String sampleCode);

    String getSampleCode();

    void setComment(String comment);

    String getComment();

    void setImportHash(String importHash);

    String getImportHash();

    void setInvalid(boolean invalid);

    boolean isInvalid();

    boolean getInvalid();

    void setSupplier(Supplier supplier);

    Supplier getSupplier();

    void setProduct(Product product);

    Product getProduct();

    void setDedicatedClient(Client dedicatedClient);

    Client getDedicatedClient();

    void setOrigin(Country origin);

    Country getOrigin();

} //Batch
